import { Construct } from 'constructs';
/**
 * Utilities class used across the different resources
 */
export declare class Utils {
    /**
     * Sanitize a string by removing upper case and replacing special characters except underscore
     * @param toSanitize the string to sanitize
     */
    static stringSanitizer(toSanitize: string): string;
    /**
     * Create a random string to be used as a seed for IAM User password
     * @param name the string to which to append a random string
     */
    static randomize(name: string): string;
    /**
     * Read a YAML file from the path provided and return it
     * @param path the path to the file
     */
    static readYamlDocument(path: string): string;
    /**
     * Take a document stored as string and load it as YAML
     * @param document the document stored as string
     */
    static loadYaml(document: string): any;
    /**
     * Convert a string to PascalCase
     * @param text the string to convert to PascalCase
     * @returns the string in Pascal case
     */
    static toPascalCase(text: string): string;
    /**
     * Generate an 8 character hash from a string based on HMAC algorithm
     * @param text the text to hash
     * @return the hash
     */
    static generateHash(text: string): string;
    /**
     * Generate a unique hash of 8 characters from the CDK scope using its path and the stack name.
     * @param scope the CDK construct scope
     * @param id the CDK ID of the construct
     * @returns the hash
     */
    static generateUniqueHash(scope: Construct, id?: string): string;
    /**
     * Validate a provided string is a valid account ID
     * @param accountId the account ID to validate
     * @returns true if the account ID is valid, false otherwise
     */
    static validateAccountId(accountId: string): boolean;
}
